==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControl/src/com/clustercontrol/monitor/run/bean/MonitorTypeConstant.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.run.bean;

import com.clustercontrol.util.Messages;

/**
 * ƻȽ꥿饹
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class MonitorTypeConstant {
	/** (ƻȽ꥿פμ) */
	public static final int TYPE_TRUTH = 0;
	
	/** (ƻȽ꥿פμ) */
	public static final int TYPE_NUMERIC = 1;
	
	/** ʸ(ƻȽ꥿פμ) */
	public static final int TYPE_STRING = 2;
	
	/** (ƻȽ꥿פμ) */
	public static final String STRING_TRUTH = Messages.getString("truth");
	
	/** (ƻȽ꥿פμ) */
	public static final String STRING_NUMERIC = Messages.getString("numeric");
	
	/** ʸ(ƻȽ꥿פμ) */
	public static final String STRING_STRING = Messages.getString("string");
	
	/**
	 * ̤ʸѴ
	 * 
	 * @param type
	 * @return
	 */
	public static String typeToString(int type) {
		if (type == TYPE_TRUTH) {
			return STRING_TRUTH;
		} else if (type == TYPE_NUMERIC) {
			return STRING_NUMERIC;
		} else if (type == TYPE_STRING) {
			return STRING_STRING;
		}
		return "";
	}
	
	/**
	 * ʸ󤫤̤Ѵ
	 * 
	 * @param type
	 * @return
	 */
	public static int stringToType(String string) {
		if (string.equals(STRING_TRUTH)) {
			return TYPE_TRUTH;
		} else if (string.equals(STRING_NUMERIC)) {
			return TYPE_NUMERIC;
		} else if (string.equals(STRING_STRING)) {
			return TYPE_STRING;
		}
		return -1;
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControl/src/com/clustercontrol/monitor/run/bean/MonitorTypeConstant.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.run.bean;

import com.clustercontrol.util.Messages;

/**
 * 監視判定タイプ定数クラス
 * 
 * @version 2.1.0
 * @since 2.1.0
 */
public class MonitorTypeConstant {
	/** 真偽値(監視判定タイプの種別) */
	public static final int TYPE_TRUTH = 0;
	
	/** 数値(監視判定タイプの種別) */
	public static final int TYPE_NUMERIC = 1;
	
	/** 文字列(監視判定タイプの種別) */
	public static final int TYPE_STRING = 2;
	
	/** 真偽値(監視判定タイプの種別) */
	public static final String STRING_TRUTH = Messages.getString("truth");
	
	/** 数値(監視判定タイプの種別) */
	public static final String STRING_NUMERIC = Messages.getString("numeric");
	
	/** 文字列(監視判定タイプの種別) */
	public static final String STRING_STRING = Messages.getString("string");
	
	/**
	 * 種別から文字列に変換する
	 * 
	 * @param type
	 * @return
	 */
	public static String typeToString(int type) {
		if (type == TYPE_TRUTH) {
			return STRING_TRUTH;
		} else if (type == TYPE_NUMERIC) {
			return STRING_NUMERIC;
		} else if (type == TYPE_STRING) {
			return STRING_STRING;
		}
		return "";
	}
	
	/**
	 * 文字列から種別に変換する
	 * 
	 * @param type
	 * @return
	 */
	public static int stringToType(String string) {
		if (string.equals(STRING_TRUTH)) {
			return TYPE_TRUTH;
		} else if (string.equals(STRING_NUMERIC)) {
			return TYPE_NUMERIC;
		} else if (string.equals(STRING_STRING)) {
			return TYPE_STRING;
		}
		return -1;
	}
}
